import * as cdk from 'aws-cdk-lib';
import * as iam from 'aws-cdk-lib/aws-iam';
import { CfnPermissionSet } from 'aws-cdk-lib/aws-sso/lib/sso.generated';
import { IdentityStoreUserProps } from './identity-store-user';
import { DLzOrganization } from '../../data-landing-zone-types';
import { DlzStack } from '../dlz-stack/index';
/**
 * A permission set in the IAM Identity Center
 */
export interface IamIdentityCenterPermissionSetProps {
    readonly name: string;
    readonly description?: string;
    readonly inlinePolicyStatement?: iam.PolicyStatement;
    readonly managedPolicyArns?: string[];
    readonly permissionsBoundary?: cdk.IResolvable | CfnPermissionSet.PermissionsBoundaryProperty;
    readonly sessionDuration?: cdk.Duration;
}
/**
 * An access group in the IAM Identity Center
 */
export interface IamIdentityCenterAccessGroupProps {
    readonly name: string;
    readonly description?: string;
    readonly userNames?: string[];
    readonly permissionSetName: string;
    readonly accountNames: string[];
}
export interface IamIdentityCenterProps {
    readonly arn: string;
    readonly id: string;
    readonly storeId: string;
    readonly users?: IdentityStoreUserProps[];
    readonly permissionSets?: IamIdentityCenterPermissionSetProps[];
    readonly accessGroups?: IamIdentityCenterAccessGroupProps[];
}
/**
 * The IAM Identity Center
 */
export declare class IamIdentityCenter {
    constructor(dlzStack: DlzStack, organization: DLzOrganization, iamIdentityCenter: IamIdentityCenterProps);
}
