import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { PutPermissionsBoundaryToPermissionSetRequest, PutPermissionsBoundaryToPermissionSetResponse } from "../models/models_0";
import { ServiceInputTypes, ServiceOutputTypes, SSOAdminClientResolvedConfig } from "../SSOAdminClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link PutPermissionsBoundaryToPermissionSetCommand}.
 */
export interface PutPermissionsBoundaryToPermissionSetCommandInput extends PutPermissionsBoundaryToPermissionSetRequest {
}
/**
 * @public
 *
 * The output of {@link PutPermissionsBoundaryToPermissionSetCommand}.
 */
export interface PutPermissionsBoundaryToPermissionSetCommandOutput extends PutPermissionsBoundaryToPermissionSetResponse, __MetadataBearer {
}
declare const PutPermissionsBoundaryToPermissionSetCommand_base: {
    new (input: PutPermissionsBoundaryToPermissionSetCommandInput): import("@smithy/smithy-client").CommandImpl<PutPermissionsBoundaryToPermissionSetCommandInput, PutPermissionsBoundaryToPermissionSetCommandOutput, SSOAdminClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: PutPermissionsBoundaryToPermissionSetCommandInput): import("@smithy/smithy-client").CommandImpl<PutPermissionsBoundaryToPermissionSetCommandInput, PutPermissionsBoundaryToPermissionSetCommandOutput, SSOAdminClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Attaches an Amazon Web Services managed or customer managed policy to the specified <a>PermissionSet</a> as a permissions boundary.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { SSOAdminClient, PutPermissionsBoundaryToPermissionSetCommand } from "@aws-sdk/client-sso-admin"; // ES Modules import
 * // const { SSOAdminClient, PutPermissionsBoundaryToPermissionSetCommand } = require("@aws-sdk/client-sso-admin"); // CommonJS import
 * const client = new SSOAdminClient(config);
 * const input = { // PutPermissionsBoundaryToPermissionSetRequest
 *   InstanceArn: "STRING_VALUE", // required
 *   PermissionSetArn: "STRING_VALUE", // required
 *   PermissionsBoundary: { // PermissionsBoundary
 *     CustomerManagedPolicyReference: { // CustomerManagedPolicyReference
 *       Name: "STRING_VALUE", // required
 *       Path: "STRING_VALUE",
 *     },
 *     ManagedPolicyArn: "STRING_VALUE",
 *   },
 * };
 * const command = new PutPermissionsBoundaryToPermissionSetCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param PutPermissionsBoundaryToPermissionSetCommandInput - {@link PutPermissionsBoundaryToPermissionSetCommandInput}
 * @returns {@link PutPermissionsBoundaryToPermissionSetCommandOutput}
 * @see {@link PutPermissionsBoundaryToPermissionSetCommandInput} for command's `input` shape.
 * @see {@link PutPermissionsBoundaryToPermissionSetCommandOutput} for command's `response` shape.
 * @see {@link SSOAdminClientResolvedConfig | config} for SSOAdminClient's `config` shape.
 *
 * @throws {@link AccessDeniedException} (client fault)
 *  <p>You do not have sufficient access to perform this action.</p>
 *
 * @throws {@link ConflictException} (client fault)
 *  <p>Occurs when a conflict with a previous successful write is detected. This generally
 *             occurs when the previous write did not have time to propagate to the host serving the
 *             current request. A retry (with appropriate backoff logic) is the recommended response to
 *             this exception.</p>
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>The request processing has failed because of an unknown error, exception, or failure
 *             with an internal server.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>Indicates that a requested resource is not found.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>Indicates that the principal has crossed the throttling limits of the API
 *             operations.</p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>The request failed because it contains a syntax error.</p>
 *
 * @throws {@link SSOAdminServiceException}
 * <p>Base exception class for all service exceptions from SSOAdmin service.</p>
 *
 * @public
 */
export declare class PutPermissionsBoundaryToPermissionSetCommand extends PutPermissionsBoundaryToPermissionSetCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: PutPermissionsBoundaryToPermissionSetRequest;
            output: {};
        };
        sdk: {
            input: PutPermissionsBoundaryToPermissionSetCommandInput;
            output: PutPermissionsBoundaryToPermissionSetCommandOutput;
        };
    };
}
